import { Aff } from './aff';
import { Sequence } from 'gensequence';
import { WordInfo } from './types';
export { WordInfo } from './types';
export interface HunspellSrcData {
    /** The Aff rules to use with the dictionary entries */
    aff: Aff;
    /** the hunspell dictionary entries complete with affix flags */
    dic: string[];
}
export declare class IterableHunspellReader implements Iterable<string> {
    readonly src: HunspellSrcData;
    readonly aff: Aff;
    constructor(src: HunspellSrcData);
    get dic(): string[];
    set maxDepth(value: number);
    get maxDepth(): number;
    /** the number of .dic entries */
    get size(): number;
    /**
     * @internal
     */
    dicWordsSeq(): Sequence<WordInfo>;
    /**
     * iterates through the root words of the dictionary
     */
    iterateRootWords(): Iterable<string>;
    iterateWords(): Iterable<string>;
    /**
     * Iterator for all the words in the dictionary. The words are in the order found in the .dic after the
     * transformations have been applied. No filtering is done based upon the AFF flags.
     */
    [Symbol.iterator](): Sequence<string>;
    /**
     * create an iterable sequence of the words in the dictionary.
     *
     * @param tapPreApplyRules -- optional function to be called before rules are applied to a word.
     *                            It is mostly used for monitoring progress in combination with `size`.
     */
    seqAffWords(tapPreApplyRules?: (w: string, index: number) => any, maxDepth?: number): Sequence<import("./aff").AffWord>;
    /**
     * @internal
     */
    seqWords(): Sequence<string>;
    /**
     * @internal
     */
    seqRootWords(): Sequence<string>;
    static createFromFiles(affFile: string, dicFile: string): Promise<IterableHunspellReader>;
}
export declare function createMatchingWordsFilter(): (t: string) => boolean;
